import 'package:flutter/material.dart';

import 'nx_text_field.dart';

class NxSelectDate extends StatefulWidget {
  const NxSelectDate({
    Key? key,
    this.icon,
    this.text = "",
    this.initialDate,
    this.lastDate,
    this.isLoading = false,
    this.label = "",
    this.textError,
    this.onSelected,
    this.borderBottom = true,
    this.height,
    this.padding,
    this.margin,
    this.borderRadius,
    this.color = Colors.transparent,
    this.borderColor,
    this.boxShadow,
  }) : super(key: key);

  final String label;
  final String? textError;
  final Widget? icon;
  final bool isLoading;
  final String text;
  final DateTime? initialDate;
  final DateTime? lastDate;
  final ValueChanged<DateTime>? onSelected;
  final bool borderBottom;
  final double? height;
  final double? padding;
  final double? margin;
  final double? borderRadius;
  final Color? borderColor;
  final Color? color;
  final List<BoxShadow>? boxShadow;

  @override
  _NxSelectDateState createState() => _NxSelectDateState();
}

class _NxSelectDateState extends State<NxSelectDate> {
  @override
  Widget build(BuildContext context) {
    return SelectionBorderBottom(
      label: widget.label,
      textError: widget.textError,
      icon: widget.icon,
      isLoading: widget.isLoading,
      text: widget.text,
      isSelected: widget.initialDate != null,
      suffixIcon: Icons.calendar_today,
      onTap: () => selectDate(context),
      borderBottom: widget.borderBottom,
      height: widget.height,
      padding: widget.padding,
      margin: widget.margin,
      borderRadius: widget.borderRadius,
      borderColor: widget.borderColor,
      color: widget.color,
      boxShadow: widget.boxShadow,
    );
  }

  Future selectDate(BuildContext context) async {
    var lastDate = DateTime.now();
    lastDate.add(Duration(days: 360));
    if(widget.lastDate != null) {
      lastDate = widget.lastDate!;
    }

    final DateTime? picked = await showDatePicker(
      context: context,
      initialDate: widget.initialDate ?? DateTime.now(),
      firstDate: DateTime(1960),
      lastDate: lastDate,
    );
    if (picked != null && picked != widget.initialDate) {
      widget.onSelected?.call(picked);
    }
  }
}
